@@ -166,6 +166,10 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_0023(self):
         self.do_unification('0023')
 
+    # Wildcard action
+    def test_0024(self):
+        self.do_unification('0024')
+
     # Extra test, failing ActivationDate
     def test_0050(self):
         self.assertRaises( cppa3.unify.UnificationException, self.do_unification, '0210' )
@@ -291,6 +295,11 @@ class CPPA3TestCase( unittest.TestCase ):
         self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '0314')
 
 
+    # XKMS
+    def test_0320(self):
+        self.do_unification('0320')
+
+
     """
     0400 TLS tests
     """
@@ -379,6 +388,13 @@ class CPPA3TestCase( unittest.TestCase ):
         # E-SENS AS4 PoC for A and B
         self.do_unification('1011')
 
+    def test_1012(self):
+        # Variant of 1011 that uses channel features
+        self.do_unification('1012')
+
+
+    # ENTSOG AS4 tests
+    # To do
 
     # MEPs
     # 1100 range
@@ -529,6 +545,20 @@ class CPPA3TestCase( unittest.TestCase ):
     # AS4 and ReceiptHandling, Synchronous, Non-Repudiation
 
 
+    # AS4 ReceptionAwareness channel feature
+    # Both sides
+    def test_1290(self):
+        self.do_unification('1290')
+
+    # One side
+    def test_1291(self):
+        self.do_unification('1291')
+
+    # Other side
+    def test_1292(self):
+        self.do_unification('1292')
+
+
     # 1300 range
     # Compression and Packaging
 
@@ -634,6 +664,7 @@ class CPPA3TestCase( unittest.TestCase ):
     def test_2127(self):
         self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '2127')
 
+
     # Encryption
     # Base case, data encryption and certificate reference
     def test_2140(self):
@@ -677,6 +708,20 @@ class CPPA3TestCase( unittest.TestCase ):
     #def test_2170(self):
     #    self.assertRaises(cppa3.unify.UnificationException, self.do_unification, '2171')
 
+    # Channel features
+
+    # WSSecurityBinding is a channel feature on both sides, or on on of the two sides
+    def test_2200(self):
+        self.do_unification('2200')
+
+    def test_2201(self):
+        self.do_unification('2201')
+
+    def test_2202(self):
+        self.do_unification('2200')
+
+
+
     # Packaging
 
 
@@ -971,7 +1016,7 @@ def reset_timestamped_values_for_compare(cpa):
         if len(element_to_edit_l) > 0:
             for el in element_to_edit_l:
                 value = el.text
-                logging.error('Resetting {} from {}'.format(path, value))
+                logging.info('Resetting {} from {}'.format(path, value))
                 el.text = 'NONE'
     return cpa_to_edit
 
